@@ -50,6 +50,7 @@
 #include <terminal/terminal-window-dropdown.h>
 
 #define ACCEL_MAP_PATH "xfce4/terminal/accels.scm"
+#define TERMINAL_DESKTOP_FILE (DATADIR "/applications/xfce4-terminal.desktop")
 
 
 
@@ -60,7 +61,6 @@ static void     terminal_app_update_tab_key_accels    (gpointer            data,
                                                        guint               accel_key,
                                                        GdkModifierType     accel_mods,
                                                        gboolean            changed);
-static void     terminal_app_update_mnemonics         (TerminalApp        *app);
 static void     terminal_app_update_windows_accels    (gpointer            user_data);
 static gboolean terminal_app_accel_map_load           (gpointer            user_data);
 static gboolean terminal_app_accel_map_save           (gpointer            user_data);
@@ -139,8 +139,6 @@ terminal_app_init (TerminalApp *app)
                             G_CALLBACK (terminal_app_update_accels), app);
   g_signal_connect_swapped (G_OBJECT (app->preferences), "notify::shortcuts-no-helpkey",
                             G_CALLBACK (terminal_app_update_accels), app);
-  g_signal_connect_swapped (G_OBJECT (app->preferences), "notify::shortcuts-no-mnemonics",
-                            G_CALLBACK (terminal_app_update_mnemonics), app);
 
   /* remember the original menu bar accel */
   g_object_get (G_OBJECT (gtk_settings_get_default ()),
@@ -148,11 +146,10 @@ terminal_app_init (TerminalApp *app)
                 NULL);
 
   terminal_app_update_accels (app);
-  terminal_app_update_mnemonics (app);
 
   /* schedule accel map load and update windows when finished */
-  app->accel_map_load_id = g_idle_add_full (G_PRIORITY_LOW, terminal_app_accel_map_load, app,
-                                            terminal_app_update_windows_accels);
+  app->accel_map_load_id = gdk_threads_add_idle_full (G_PRIORITY_LOW, terminal_app_accel_map_load, app,
+                                                      terminal_app_update_windows_accels);
 }
 
 
@@ -169,8 +166,10 @@ terminal_app_finalize (GObject *object)
   if (app->accel_map != NULL)
     g_object_unref (G_OBJECT (app->accel_map));
   if (G_UNLIKELY (app->accel_map_save_id != 0))
-    g_source_remove (app->accel_map_save_id);
-  terminal_app_accel_map_save (app);
+    {
+      g_source_remove (app->accel_map_save_id);
+      terminal_app_accel_map_save (app);
+    }
 
   for (lp = app->windows; lp != NULL; lp = lp->next)
     {
@@ -183,7 +182,6 @@ terminal_app_finalize (GObject *object)
   g_slist_free (app->windows);
 
   g_signal_handlers_disconnect_by_func (G_OBJECT (app->preferences), G_CALLBACK (terminal_app_update_accels), app);
-  g_signal_handlers_disconnect_by_func (G_OBJECT (app->preferences), G_CALLBACK (terminal_app_update_mnemonics), app);
   g_object_unref (G_OBJECT (app->preferences));
 
   if (app->initial_menu_bar_accel != NULL)
@@ -249,21 +247,6 @@ terminal_app_update_tab_key_accels (gpointer         data,
 
 
 
-static void
-terminal_app_update_mnemonics (TerminalApp *app)
-{
-  gboolean no_mnemonics;
-
-  g_object_get (G_OBJECT (app->preferences),
-                "shortcuts-no-mnemonics", &no_mnemonics,
-                NULL);
-  g_object_set (G_OBJECT (gtk_settings_get_default ()),
-                "gtk-enable-mnemonics", !no_mnemonics,
-                NULL);
-}
-
-
-
 static void
 terminal_app_update_windows_accels (gpointer user_data)
 {
@@ -314,7 +297,7 @@ terminal_app_accel_map_changed (TerminalApp *app)
     }
 
   /* schedule new save */
-  app->accel_map_save_id = g_timeout_add_seconds (10, terminal_app_accel_map_save, app);
+  app->accel_map_save_id = gdk_threads_add_timeout_seconds (10, terminal_app_accel_map_save, app);
 }
 
 
@@ -369,18 +352,8 @@ terminal_app_unset_urgent_bell (TerminalWindow *window,
                                 GdkEvent       *event,
                                 TerminalApp    *app)
 {
-  GtkWidget *toplevel;
-  gboolean   enabled;
-
-  g_object_get (G_OBJECT (app->preferences),
-                "misc-bell-urgent", &enabled,
-                NULL);
-
-  if (enabled)
-    {
-      toplevel = gtk_widget_get_toplevel (GTK_WIDGET (window));
-      gtk_window_set_urgency_hint (GTK_WINDOW (toplevel), FALSE);
-    }
+  GtkWidget *toplevel = gtk_widget_get_toplevel (GTK_WIDGET (window));
+  gtk_window_set_urgency_hint (GTK_WINDOW (toplevel), FALSE);
 
   return FALSE;
 }
@@ -804,6 +777,10 @@ terminal_app_open_window (TerminalApp        *app,
                                                   attr->menubar,
                                                   attr->toolbar);
 
+          /* drop-down window can be maximized */
+          if (attr->maximize)
+            gtk_window_maximize (GTK_WINDOW (window));
+
           /* put it on the correct screen/display */
           screen = terminal_app_find_screen (attr_display, attr_screen_num);
           gtk_window_set_screen (GTK_WINDOW (window), screen);
@@ -1020,6 +997,7 @@ terminal_app_process (TerminalApp  *app,
                                                      PACKAGE_NAME ".desktop");
       if (xfce_sm_client_connect (app->session_client, &err))
         {
+          xfce_sm_client_set_desktop_file (app->session_client, TERMINAL_DESKTOP_FILE);
           g_signal_connect (G_OBJECT (app->session_client), "save-state",
                             G_CALLBACK (terminal_app_save_yourself), app);
           g_signal_connect (G_OBJECT (app->session_client), "quit",
