@@ -45,7 +45,7 @@ enum
 static void       terminal_encoding_action_finalize         (GObject                *object);
 static GtkWidget *terminal_encoding_action_create_menu_item (GtkAction              *action);
 static void       terminal_encoding_action_menu_shown       (GtkWidget              *menu,
-                                                             TerminalEncodingAction *encoding_action);
+                                                             TerminalEncodingAction *action);
 
 
 
@@ -133,7 +133,7 @@ static const gchar *terminal_encodings_charsets[][8] =
   /* Georgian */
   { "GEORGIAN-PS", NULL },
   /* Unicode */
-  { "UTF-8", "UTF-16", "UTF-7", "UCS-2", NULL },
+  { "UTF-8", NULL },
   /* Other */
   { "IBM874", "TSCII", NULL },
 };
