@@ -87,6 +87,14 @@ typedef enum /*< enum,prefix=TERMINAL_CURSOR_SHAPE >*/
   TERMINAL_CURSOR_SHAPE_UNDERLINE
 } TerminalCursorShape;
 
+typedef enum /*< enum,prefix=TERMINAL_TEXT_BLINK_MODE >*/
+{
+  TERMINAL_TEXT_BLINK_MODE_NEVER,
+  TERMINAL_TEXT_BLINK_MODE_FOCUSED,
+  TERMINAL_TEXT_BLINK_MODE_UNFOCUSED,
+  TERMINAL_TEXT_BLINK_MODE_ALWAYS
+} TerminalTextBlinkMode;
+
 GType                terminal_preferences_get_type  (void) G_GNUC_CONST;
 
 TerminalPreferences *terminal_preferences_get       (void);
