@@ -130,6 +130,14 @@ gboolean        terminal_screen_has_foreground_process    (TerminalScreen *scree
 void            terminal_screen_feed_text                 (TerminalScreen *screen,
                                                            const char     *text);
 
+const gchar    *terminal_screen_get_custom_fg_color       (TerminalScreen *screen);
+
+const gchar    *terminal_screen_get_custom_bg_color       (TerminalScreen *screen);
+
+const gchar    *terminal_screen_get_custom_title_color    (TerminalScreen *screen);
+void            terminal_screen_set_custom_title_color    (TerminalScreen *screen,
+                                                           const gchar    *color);
+
 G_END_DECLS
 
 #endif /* !TERMINAL_SCREEN_H */
